SWDEV-549309 - Ensure that the kernel is issued to a stream that is ass… (#552)

* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device

* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device in atomic tests

* SWDEV-549309 - Added fix for Unit_hipMallocFromPoolAsync_Multidevice_Concurrent test

* SWDEV-549309 - Added fix for Unit_hipMemcpyPeerAsync_Positive_Default

* SWDEV-549309 - Added fix for Unit_hipStreamAttachMemAsync_Positive_AttachGlobal and Unit_hipGetProcAddress_GraphAPIs_AddMemsetMemcpyNodes

[ROCm/hip-tests commit: d21a95cea8]
This commit is contained in:
Assiouras, Ioannis
2025-08-14 07:20:56 +01:00
committed by GitHub
parent 17d12dff14
commit 5283a114b2
15 changed files with 38 additions and 21 deletions
@@ -446,6 +446,7 @@ void TestCore(const TestParams& p) {
// Launch Kernel
for (auto i = 0u; i < p.num_devices; ++i) {
HIP_CHECK(hipSetDevice(i));
for (auto j = 0u; j < p.kernel_count; ++j) {
const auto& stream = streams[i * p.kernel_count + j].stream();
const auto old_vals = old_vals_devs[i].ptr() + j * p.ThreadCount();
@@ -272,6 +272,7 @@ void TestCore(const TestParams& p) {
}
// Launch Kernel and get back old vals
for (auto i = 0u; i < p.num_devices; ++i) {
HIP_CHECK(hipSetDevice(i));
for (auto j = 0u; j < p.kernel_count; ++j) {
const auto& stream = streams[i * p.kernel_count + j].stream();
const auto old_vals = old_vals_devs[i].ptr() + j * p.ThreadCount();
@@ -302,6 +302,7 @@ void TestCore(const TestParams& p) {
// Launch kernel
for (auto i = 0u; i < p.num_devices; ++i) {
HIP_CHECK(hipSetDevice(i));
for (auto j = 0u; j < p.kernel_count; ++j) {
const auto& stream = streams[i * p.kernel_count + j].stream();
const auto old_vals = old_vals_devs[i].ptr() + j * p.ThreadCount();